@@ -11,7 +11,7 @@ predict.fair.model = function(object, ...) {
 
 }#PREDICT.FAIR.MODELS
 
-predict.two.stages = function(object, new.predictors, new.sensitive) {
+predict.two.stages = function(object, new.predictors, new.sensitive, type) {
 
   # check the predictors and the sensitive attributes.
   new.predictors = check.data(new.predictors, min.nobs = 1, varletter = "X")
@@ -44,12 +44,59 @@ predict.two.stages = function(object, new.predictors, new.sensitive) {
   if (any(colnames(newdata) != names(coefs)))
     newdata = newdata[, names(coefs)]
 
-  return(as.vector(newdata %*% coefs))
+  linear.predictor = as.vector(newdata %*% coefs)
+
+  if (is(object, fair.regressions) ||
+      (is(object, fair.family) && (object$main$family == "gaussian"))) {
+
+    # check the type of fitted values.
+    check.label(type, c("response", "link"), "prediction type")
+
+    return(linear.predictor)
+
+  }#THEN
+  else if (is(object, fair.classifiers) ||
+           (is(object, fair.family) && (object$main$family == "binomial"))) {
+
+    # check the type of fitted values.
+    check.label(type, c("response", "class", "link"), "prediction type")
+
+    return(classifier.prediction(linear.predictor, type = type,
+             labels = object$data$response$levels[["response"]]))
+
+  }#THEN
 
 }#PREDICT.TWO.STAGES
 
+classifier.prediction = function(linear.predictor, type, labels) {
+
+  # compute the probability of success.
+  probs = 1 / (1 + exp(-linear.predictor))
+
+  if (type == "link") {
+
+    # predict on the scale of the linear component of the model.
+    return(linear.predictor)
+
+  }#THEN
+  else if (type == "response") {
+
+    # predict the probability of success.
+    return(probs)
+
+  }#THEN
+  else if (type == "class") {
+
+    # predict the class label.
+    return(prob2class(probs, labels = labels))
+
+  }#THEN
+
+}#CLASSIFIER.PREDICTION
+
 # predict new observations for the fair regression in Komiyama et al. (2018).
-predict.nclm = function(object, new.predictors, new.sensitive, ...) {
+predict.nclm = function(object, new.predictors, new.sensitive,
+    type = "response", ...) {
 
   if (!is(object, "nclm"))
     stop("'object' must be an 'nclm' object.")
@@ -57,12 +104,13 @@ predict.nclm = function(object, new.predictors, new.sensitive, ...) {
   check.unused.args(list(...), character(0))
 
   predict.two.stages(object = object, new.predictors = new.predictors,
-    new.sensitive = new.sensitive)
+    new.sensitive = new.sensitive, type = type)
 
 }#PREDICT.NCLM
 
 # predict new observations for the fair ridge regression.
-predict.frrm = function(object, new.predictors, new.sensitive, ...) {
+predict.frrm = function(object, new.predictors, new.sensitive,
+    type = "response", ...) {
 
   if (!is(object, "frrm"))
     stop("'object' must be an 'frrm' object.")
@@ -70,11 +118,25 @@ predict.frrm = function(object, new.predictors, new.sensitive, ...) {
   check.unused.args(list(...), character(0))
 
   predict.two.stages(object = object, new.predictors = new.predictors,
-    new.sensitive = new.sensitive)
+    new.sensitive = new.sensitive, type = type)
 
 }#PREDICT.FRRM
 
-# predict new observations for the Zafar's logistic regression.
+# predict new observations for the fair generalized ridge regression.
+predict.fgrrm = function(object, new.predictors, new.sensitive,
+    type = "response", ...) {
+
+  if (!is(object, "fgrrm"))
+    stop("'object' must be an 'fgrrm' object.")
+
+  check.unused.args(list(...), character(0))
+
+  predict.two.stages(object = object, new.predictors = new.predictors,
+    new.sensitive = new.sensitive, type = type)
+
+}#PREDICT.FGRRM
+
+# predict new observations for Zafar's logistic regression.
 predict.zlrm = function(object, new.predictors, type = "response", ...) {
 
   if (!is(object, "zlrm"))
@@ -102,30 +164,42 @@ predict.zlrm = function(object, new.predictors, type = "response", ...) {
     new.predictors = new.predictors[, names(coefs)]
 
   # compute the linear component of the model.
-  nfit = as.vector(new.predictors %*% coefs)
-  # compute the probability of success.
-  probs = 1 / (1 + exp(-nfit))
+  linear.predictor = as.vector(new.predictors %*% coefs)
 
-  if (type == "link") {
-
-    # predict on the scale of the linear component of the model.
-    return(nfit)
-
-  }#THEN
-  else if (type == "response") {
-
-    # predict the probability of success.
-    predictions = probs
-
-  }#THEN
-  else if (type == "class") {
-
-    # predict the class label.
-    predictions =
-      prob2class(probs, labels = object$data$response$levels[["response"]])
-
-  }#THEN
-
-  return(predictions)
+  classifier.prediction(linear.predictor, type = type,
+    labels = object$data$response$levels[["response"]])
 
 }#PREDICT.ZLRM
+
+# predict new observations for Zafar's linear regression.
+predict.zlm = function(object, new.predictors, type = "response", ...) {
+
+  if (!is(object, "zlm"))
+    stop("'object' must be a 'zlm' object.")
+
+  # check the type of fitted values.
+  check.label(type, c("response", "link"), "prediction type")
+
+  check.unused.args(list(...), character(0))
+
+  # check the predictors, in themselves and against the data the model was
+  # fitted from.
+  new.predictors = check.data(new.predictors, min.nobs = 1, varletter = "X")
+  new.predictors = check.data.vs.info(new.predictors, object$data$predictors)
+  new.predictors = design.matrix(new.predictors)
+
+  # extract the coefficients of the main model.
+  coefs = coef(object)
+
+  # check that they match with the variables, and that they appear in the same
+  # order.
+  if (!setequal(colnames(new.predictors), names(coefs)))
+    stop("'new.predictors' have different variables than the model.")
+  if (any(colnames(new.predictors) != names(coefs)))
+    new.predictors = new.predictors[, names(coefs)]
+
+  linear.predictor = as.vector(new.predictors %*% coefs)
+
+  return(linear.predictor)
+
+}#PREDICT.ZLM
