@@ -30,7 +30,7 @@ check.covariance.matrix = function(covmat, nvars, what) {
   if (dims[1] != dims[2])
     stop("the covariance matrix of ", what, " must be a square matrix.")
   if (dims[1] != nvars)
-    stop("the covatiance matrix of ", what,
+    stop("the covariance matrix of ", what,
          " should be a square matrix with dimension ", nvars,
          " but it has dimension ", dims[1], "x", dims[2], ".")
 
@@ -42,7 +42,7 @@ check.covariance.matrix = function(covmat, nvars, what) {
 
 }#CHECK.COVARIANCE.MATRIX
 
-# check the proportion of variance explained by sensitive attributes.
+# check the unfairness tuning parameter.
 check.fairness.level = function(unfairness, scalar = TRUE) {
 
   if (scalar) {
@@ -55,11 +55,25 @@ check.fairness.level = function(unfairness, scalar = TRUE) {
 
     if (missing(unfairness))
       unfairness = seq(from = 0.00, to = 1, by = 0.02)
-    else if (!is.probability.vector(unfairness))
+    else if (!is.probability.vector(unfairness) || (length(unfairness) < 2))
       stop("'unfairness' should be a vector of numbers between 0 and 1.")
 
   }#ELSE
 
-  return(unfairness)
+  # make sure the values are sorted, to make it easier to use them to draw
+  # profile plots.
+  return(sort(unfairness))
 
 }#CHECK.FAIRNESS.LEVEL
+
+# check the lambda penalty coefficient used for regularisation.
+check.ridge.penalty = function(lambda) {
+
+    if (missing(lambda))
+      lambda = 0
+    else if (!is.non.negative(lambda))
+      stop('lambda should be a non-negative number.')
+
+    return(lambda)
+
+}#CHECK.RIDGE.PENALTY
